#
# spec file for package perl-Minion
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Minion
Version:        5.08
Release:        3.1
%define cpan_name Minion
Summary:        Job queue
License:        Artistic-2.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Minion/
Source0:        http://www.cpan.org/authors/id/S/SR/SRI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Mojolicious) >= 6.0
Requires:       perl(Mojolicious) >= 6.0
%{perl_requires}

%description
Minion is a job queue for the at http://mojolicious.org real-time web
framework, with support for multiple named queues, priorities, delayed
jobs, job dependencies, job results, retries with backoff, statistics,
distributed workers, parallel processing, autoscaling, resource leak
protection and multiple backends (such as at http://www.postgresql.org).

Job queues allow you to process time and/or computationally intensive tasks
in background processes, outside of the request/response lifecycle. Among
those tasks you'll commonly find image resizing, spam filtering, HTTP
downloads, building tarballs, warming caches and basically everything else
you can imagine that's not super fast.

  use Mojolicious::Lite;

  plugin Minion => {Pg => 'postgresql://sri:s3cret@localhost/test'};

  # Slow task
  app->minion->add_task(poke_mojo => sub {
    my $job = shift;
    $job->app->ua->get('mojolicious.org');
    $job->app->log->debug('We have poked mojolicious.org for a visitor');
  });

  # Perform job in a background worker process
  get '/' => sub {
    my $c = shift;
    $c->minion->enqueue('poke_mojo');
    $c->render(text => 'We will poke mojolicious.org for you soon.');
  };

  app->start;

Background worker processes are usually started with the command
Minion::Command::minion::worker, which becomes automatically available when
an application loads the plugin Mojolicious::Plugin::Minion.

  $ ./myapp.pl minion worker

Jobs can be managed right from the command line with
Minion::Command::minion::job.

  $ ./myapp.pl minion job

Every job can fail or succeed, but not get lost, the system is eventually
consistent and will preserve job results for as long as you like, depending
on "remove_after". While individual workers can fail in the middle of
processing a job, the system will detect this and ensure that no job is
left in an uncertain state, depending on "missing_after".

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples LICENSE README.md

%changelog
* Mon May 23 2016 coolo@suse.com
- updated to 5.08
  see /usr/share/doc/packages/perl-Minion/Changes
  5.08  2016-05-20
  - Improved repair methods not to remove finished jobs with unresolved
    dependencies.
  5.07  2016-05-17
  - Added support for job dependencies. (jberger, sri)
  - Added parents option to enqueue methods in Minion and Minion::Backend::Pg.
    (jberger, sri)
  - Added children and parents fields to info method in Minion::Job and job_info
    method in Minion::Backend::Pg.
  - Added -P option to job command.
  - Improved stats methods to include jobs with unresolved dependencies in
    delayed_jobs count.
  5.06  2016-05-05
  - Improved worker command to support the TTIN, TTOU and USR1 signals.
  - Improved Minion::Backend::Pg to handle delayed and retried jobs more
    efficiently.
* Thu May  5 2016 coolo@suse.com
- updated to 5.05
  see /usr/share/doc/packages/perl-Minion/Changes
  5.05  2016-04-20
  - Added queue option to list_jobs method in Minion::Backend::Pg.
  - Improved performance of stats method in Minion::Backend::Pg slightly.
  5.04  2016-04-19
  - Added EXPERIMENTAL delayed_jobs field to stats method in Minion and
    Minion::Backend::Pg.
  - Updated Mojo::Pg requirement to 2.18.
  - Improved job command to show more detailed information for jobs and workers.
* Mon Apr 11 2016 coolo@suse.com
- updated to 5.03
  see /usr/share/doc/packages/perl-Minion/Changes
  5.03  2016-04-10
  - Added enqueue event to Minion. (jberger)
* Mon Apr  4 2016 coolo@suse.com
- updated to 5.02
  see /usr/share/doc/packages/perl-Minion/Changes
  5.02  2016-03-23
  - Fixed copyright notice.
* Tue Mar  8 2016 coolo@suse.com
- updated to 5.01
  see /usr/share/doc/packages/perl-Minion/Changes
  5.01  2016-02-24
  - Fixed worker command to repair in regular intervals.
* Fri Feb 19 2016 coolo@suse.com
- updated to 5.0
  see /usr/share/doc/packages/perl-Minion/Changes
  5.0  2016-02-17
  - Added start event to Minion::Job.
  - Added -R option to worker command.
  - Reduced default missing_after value to 30 minutes.
  - Reduced default remove_after value to 2 days.
  - Improved Minion::Backend::Pg performance significantly with a new index and
    PostgreSQL 9.5 features.
  - Improved Minion::Job to capture more exceptions.
  - Improved worker command to support the QUIT signal.
  - Improved worker command to repair in less regular intervals.
* Sun Feb  7 2016 coolo@suse.com
- updated to 4.06
  see /usr/share/doc/packages/perl-Minion/Changes
  4.06  2016-02-06
  - Improved performance of Minion::Backend::Pg slightly.
  4.05  2016-02-05
  - Improved Minion::Backend::Pg to check the PostgreSQL version.
* Wed Jan 27 2016 coolo@suse.com
- updated to 4.04
  see /usr/share/doc/packages/perl-Minion/Changes
  4.04  2016-01-23
  - Updated Minion::Backend::Pg to use new Mojo::Pg features.
* Tue Jan 19 2016 coolo@suse.com
- updated to 4.03
  see /usr/share/doc/packages/perl-Minion/Changes
  4.03  2016-01-17
  - Removed an unused index from Minion::Backend::Pg.
  - Fixed a bug where the worker command would always watch the default queue.
    (avkhozov)
* Wed Jan 13 2016 coolo@suse.com
- updated to 4.02
  see /usr/share/doc/packages/perl-Minion/Changes
  4.02  2016-01-03
  - Updated links to Mojolicious website.
* Sat Nov 14 2015 coolo@suse.com
- updated to 4.01
  see /usr/share/doc/packages/perl-Minion/Changes
  4.01  2015-11-12
  - Improved retry methods to allow options to be changed for already inactive
    jobs.
* Wed Nov 11 2015 coolo@suse.com
- updated to 4.0
  see /usr/share/doc/packages/perl-Minion/Changes
  4.0  2015-11-09
  - Removed attempts attribute from Minion::Job.
  - Improved Minion::Backend::Pg to preserve more information across retries for
    debugging.
  - Fixed bug where jobs could not be retried automatically if a worker went
    away.
* Mon Nov  9 2015 coolo@suse.com
- updated to 3.03
  see /usr/share/doc/packages/perl-Minion/Changes
  3.03  2015-11-08
  - Added queues option to perform_jobs method in Minion.
* Sat Oct 31 2015 coolo@suse.com
- updated to 3.02
  see /usr/share/doc/packages/perl-Minion/Changes
  3.02  2015-10-31
  - Fixed portability issues in tests.
  3.01  2015-10-30
  - Added support retrying failed jobs automatically.
  - Added backoff attribute to Minion.
  - Added attempts attribute to Minion::Job.
  - Added attempts option to enqueue method in Minion and Minion::Backend::Pg.
  - Added -A option to job command.
  3.0  2015-10-30
  - Removed Minion::Backend::File, because DBM::Deep quickly becomes unusably
    slow, you can use the CPAN module Minion::Backend::SQLite instead.
* Fri Oct 16 2015 coolo@suse.com
- updated to 2.05
  see /usr/share/doc/packages/perl-Minion/Changes
  2.05  2015-10-15
  - Fixed bug where jobs could sometimes not be finished correctly by the worker
    command.
  2.04  2015-10-14
  - Fixed portability issue in worker command.
* Sun Oct 11 2015 coolo@suse.com
- updated to 2.03
  see /usr/share/doc/packages/perl-Minion/Changes
  2.03  2015-10-09
  - Improved commands to show all options that can affect their behavior.
* Sat Oct 10 2015 coolo@suse.com
- updated to 2.02
  see /usr/share/doc/packages/perl-Minion/Changes
  2.02  2015-10-08
  - Improved job command to show the queue in job lists.
* Sun Oct  4 2015 coolo@suse.com
- updated to 2.01
  see /usr/share/doc/packages/perl-Minion/Changes
  2.01  2015-10-02
  - Fixed Windows portability issues in tests.
* Fri Oct  2 2015 coolo@suse.com
- updated to 2.0
  see /usr/share/doc/packages/perl-Minion/Changes
  2.0  2015-10-01
  - Removed -t option from worker command.
  - Added support for multiple named queues.
  - Added retries attribute to Minion::Job.
  - Added retries argument to fail_job, finish_job and retry_job methods in
    Minion::Backend::File and Minion::Backend::Pg.
  - Added queue option to enqueue method in Minion.
  - Added queue option to enqueue and retry_job methods in Minion::Backend::File
    and Minion::Backend::Pg.
  - Added queues option to dequeue method in Minion::Worker.
  - Added queues option to dequeue method in Minion::Backend::File and
    Minion::Backend::Pg.
  - Added -q option to job and worker commands.
  - Improved worker command to be more resilient to time jumps.
  - Fixed a race condition in Minion::Backend::File and Minion::Backend::Pg
    where a retried job did not have to be dequeued again before it could be
    finished.
  1.19  2015-09-28
  - Added support for retrying jobs with a new priority.
  - Added priority option to retry method in Minion::Job.
  - Added priority option to retry_job method in Minion::Backend::File and
    Minion::Backend::Pg.
* Thu Sep  3 2015 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-Minion/Changes
  1.18  2015-08-30
  - Fixed Makefile.PL to be compliant with version 2 of the CPAN distribution
    metadata specification.
* Sat Aug 29 2015 coolo@suse.com
- updated to 1.17
  see /usr/share/doc/packages/perl-Minion/Changes
  1.17  2015-08-29
  - Fixed bug in worker command where new jobs would still be dequeued after
    receiving an INT/TERM signal.
  1.16  2015-08-28
  - Improved worker command to detect workers without heartbeat a little faster.
* Sat May 16 2015 coolo@suse.com
- updated to 1.15
  see /usr/share/doc/packages/perl-Minion/Changes
  1.15  2015-05-15
  - Added support for retrying jobs with a delay. (kwa)
  - Added delay option to retry method in Minion::Job. (kwa)
  - Added delay option to retry_job method in Minion::Backend::File. (kwa)
  - Added delay option to retry_job method in Minion::Backend::Pg. (kwa)
* Wed Apr 22 2015 coolo@suse.com
- updated to 1.14
  see /usr/share/doc/packages/perl-Minion/Changes
  1.14  2015-04-21
  - Improved performance of Minion::Backend::Pg with a new index. (avkhozov)
* Fri Mar 27 2015 coolo@suse.com
- initial package 1.13
  * created by cpanspec 1.78.08
